StepKind

Enum StepKind 

pub enum StepKind {
Show 19 variants Workdir(TemplateString), Workspace(WorkspaceTarget), Env { key: String, value: TemplateString, }, InheritEnv { keys: Vec<String>, }, Run(TemplateString), Echo(TemplateString), RunBg(TemplateString), Copy { from_current_workspace: bool, from: TemplateString, to: TemplateString, }, Symlink { from: TemplateString, to: TemplateString, }, Mkdir(TemplateString), Ls(Option<TemplateString>), Cwd, Read(Option<TemplateString>), Write { path: TemplateString, contents: Option<TemplateString>, }, WithIo { bindings: Vec<IoBinding>, cmd: Box<StepKind>, }, WithIoBlock { bindings: Vec<IoBinding>, }, CopyGit { rev: TemplateString, from: TemplateString, to: TemplateString, include_dirty: bool, }, HashSha256 { path: TemplateString, }, Exit(i32),
}

Variants



Workdir(TemplateString)



Workspace(WorkspaceTarget)



Env

Fields



InheritEnv

Directive to inherit a selective list of environment variables from the host. This is intended to be declared in the prelude/top-level only.

Fields

keys: Vec<String>


Run(TemplateString)



Echo(TemplateString)



RunBg(TemplateString)



Copy

Fields

from_current_workspace: bool


Mkdir(TemplateString)



Ls(Option<TemplateString>)



Cwd



Read(Option<TemplateString>)



Write



WithIo

Fields

bindings: Vec<IoBinding>


WithIoBlock

Fields

bindings: Vec<IoBinding>


CopyGit

Fields

include_dirty: bool


HashSha256

Fields



Exit(i32)